# AI Usage Report

We used AI tools (Primarily ChatGPT) for:

## Sprint 0

- Refining report: structuring and clarifying meeting notes and research insights to produce the report
- Researching existing solutions
- Formatting text and improving grammar of docs files
- Helping with converting written text into MD format
- Formating the meeting transcript

## Sprint 1

- Generating site on GitHub Pages for the documentation: setting up MkDocs configuration, GitHub Actions workflow, and creating the documentation site structure
- Transcribing and summarizing the meeting recording
- Providing guidance how to set up GitHub Porjects
- Structuring and formatting meeting documents

## Sprint 2

- Formatting and summarizing meeting notes
- Guidance and notes on how to write sprint retrospectives
- Providing assistance with writing action points and constraints

## Sprint 3

- Comparing summaries from experiments with and without repository URL context
- Writing methodology section for context impact experiment
- Analyzing and documenting results and conclusions from diff summary quality experiments

## Sprint 4

- Formatting and summarizing meeting notes
- Providing tips on which features can improve customer experience

## Sprint 5

- Guidance and notes on how to do the spring grooming
- Providing assistance with developing and testing the new features supported (in particular, changing the LLM used for the primary service).

## Sprint 6

- Guidance how to improve product backlog
- Assistance in token logs implementation
- Summarizing the meeting transcript
- Formatting the written texts
